# Progressive Multi-step Form

This form reveals fields progressively based on previous answers, which can be challenging for autofill systems.

Success! Form submitted successfully! The secret is: dumbledore
1 Step 1
2 Step 2
3 Review

## Basic Information

Email Address
Please enter a valid email address
Category
Please select a category

## Additional Details

Event Date
Event date is required
Preference
Option A
Option B
Option C
Please select a preference
Upload Document
Please upload a document

## Review Your Information

I agree to the Terms and Conditions
You must agree to the terms and conditions